Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(46)

Unified Diff: tools/gyp-windows.py

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/generate_version_cc.py ('k') | tools/immic/lib/src/plugins/java.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gyp-windows.py
diff --git a/tools/gyp-windows.py b/tools/gyp-windows.py
index c96a5072e6d497cd46b5e83cb5b09083c6cd95b9..9ce0e4399e2ba6d37c9f0b0d3f0bd78640a5fe68 100644
--- a/tools/gyp-windows.py
+++ b/tools/gyp-windows.py
@@ -7,24 +7,24 @@ import os
import sys
script_dir = os.path.dirname(os.path.realpath(__file__))
-fletch_src = os.path.abspath(os.path.join(script_dir, os.pardir))
+dartino_src = os.path.abspath(os.path.join(script_dir, os.pardir))
-assert os.path.exists(os.path.join(fletch_src, 'third_party', 'gyp', 'pylib'))
-sys.path.append(os.path.join(fletch_src, 'third_party', 'gyp', 'pylib'))
+assert os.path.exists(os.path.join(dartino_src, 'third_party', 'gyp', 'pylib'))
+sys.path.append(os.path.join(dartino_src, 'third_party', 'gyp', 'pylib'))
import gyp
-sys.path.append(os.path.join(fletch_src, 'tools', 'vs_dependency'))
+sys.path.append(os.path.join(dartino_src, 'tools', 'vs_dependency'))
import vs_toolchain
vs2013_runtime_dll_dirs = vs_toolchain.SetEnvironmentAndGetRuntimeDllDirs()
gyp_rc = gyp.script_main()
# TODO(herhut): Make the below work for fletch once compilation works.
if vs2013_runtime_dll_dirs:
x64_runtime, x86_runtime = vs2013_runtime_dll_dirs
vs_toolchain.CopyVsRuntimeDlls(
- os.path.join(fletch_src, "out"),
+ os.path.join(dartino_src, "out"),
(x86_runtime, x64_runtime))
sys.exit(gyp_rc)
« no previous file with comments | « tools/generate_version_cc.py ('k') | tools/immic/lib/src/plugins/java.dart » ('j') | no next file with comments »
@@ -7,24 +7,24 @@ import os
vs2013_runtime_dll_dirs = vs_toolchain.SetEnvironmentAndGetRuntimeDllDirs()
gyp_rc = gyp.script_main()
-# TODO(herhut): Make the below work for fletch once compilation works.
+# TODO(herhut): Make the below work for dartino once compilation works.
if vs2013_runtime_dll_dirs:
x64_runtime, x86_runtime = vs2013_runtime_dll_dirs

Powered by Google App Engine
This is Rietveld 408576698